﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Runtime.InteropServices.WindowsRuntime;
using Windows.Foundation;
using Windows.Foundation.Collections;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Controls.Primitives;
using Windows.UI.Xaml.Data;
using Windows.UI.Xaml.Input;
using Windows.UI.Xaml.Media;
using Windows.UI.Xaml.Navigation;

using DL_uFCoder;

// The Blank Page item template is documented at http://go.microsoft.com/fwlink/?LinkId=402352&clcid=0x409

namespace Test_uFCoder_lib
{

    /// <summary>
    /// An empty page that can be used on its own or navigated to within a Frame.
    /// </summary>
    public sealed partial class MainPage : Page
    {
        private UFR_STATUS status;

        private void prnl(string msg)
        {
            txtOut.Text += msg;
            txtOut.Text += System.Environment.NewLine;
        }

        private void wr_stat(string msg)
        {
            string m = msg;
            m += " : ";
            m += uFCoder.status2str(status);

            prnl(m);
        }

        public MainPage()
        {
            this.InitializeComponent();
            string ver;

            try
            {
                ver = "DLL version= ";
                ver += uFCoder.GetLibraryVersion();
            }
            catch (Exception ee)
            {
                ver = ee.Message;
            }

            prnl(ver);

            reader_open();
        }

        private void reader_open()
        {
            try
            {

                status = uFCoder.ReaderOpenEx(2, IntPtr.Zero, 1, IntPtr.Zero);
                wr_stat("ReaderOpenEx(2, 0, 1, 0) : RS232 115200 bps");

                // status = uFCoder.ReaderOpenEx(1, IntPtr.Zero, 1, IntPtr.Zero);
                // wr_stat("ReaderOpenEx(1, 0, 1, 0)");
            }
            catch (Exception ee)
            {
                prnl(ee.Message);
                //throw;
            }
        }

        private void bRdOpen_Click(object sender, RoutedEventArgs e)
        {
            reader_open();
        }

        private void bRdClose_Click(object sender, RoutedEventArgs e)
        {
            status = uFCoder.ReaderClose();
            wr_stat("ReaderClose()");
        }

        private void bRdInfo_Click(object sender, RoutedEventArgs e)
        {
            string reader_dsc = uFCoder.GetDescription();
            prnl(reader_dsc);
        }

        private void bRdSignal_Click(object sender, RoutedEventArgs e)
        {
            status = uFCoder.ReaderUISignal(3, 3);
            wr_stat("ReaderUISignal(3, 3)");
        }

        private void bRdCardID_Click(object sender, RoutedEventArgs e)
        {
            CARD_SAK Sak = CARD_SAK.UNKNOWN;
            byte[] baUid = new byte[10];

            status = uFCoder.GetCardIdEx(ref Sak, ref baUid);
            wr_stat("GetCardIdEx()");

            if (status == UFR_STATUS.UFR_OK)
            {
                string s;
                string hex = BitConverter.ToString(baUid);

                s = "CARD: SAK= " + Sak.ToString() + " | ";
                s += "UidSize= " + baUid.Length + " | ";
                s += "Uid= " + BitConverter.ToString(baUid);
                prnl(s);
            }
        }

        private void bClearLog_Click(object sender, RoutedEventArgs e)
        {
            txtOut.Text = String.Empty;
        }
    }
}
